aboutsummaryrefslogtreecommitdiffstats
path: root/py_bindings/example.py
diff options
context:
space:
mode:
Diffstat (limited to 'py_bindings/example.py')
-rw-r--r--py_bindings/example.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/py_bindings/example.py b/py_bindings/example.py
index 233d111..96040a9 100644
--- a/py_bindings/example.py
+++ b/py_bindings/example.py
@@ -1,8 +1,8 @@
import tempfile
from pprint import pformat, pprint
-from log_db import Value, Bound, DB
+from autere_db import Value, Bound, DB
-# TODO: This should be imported from the log_db module
+# TODO: This should be imported from the autere_db module
# but exporting type aliases does not work automatically
Record = list[Value]
@@ -40,7 +40,7 @@ db = DB \
db.upsert(Inst(1, "foo").into_record())
-#res = db.find_by("name", log_db.Value.string("foo"))
+#res = db.find_by("name", autere_db.Value.string("foo"))
#insts = [Inst.from_record(r) for r in res]
res = db.range_by("name",
Bound.unbounded(),